"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const fs_1 = tslib_1.__importDefault(require("fs"));
const path_1 = tslib_1.__importDefault(require("path"));
const renderer_1 = require("@remotion/renderer");
const log_1 = require("../utils/log");
const defaultPaths_1 = require("../config/defaultPaths");
const format_1 = tslib_1.__importDefault(require("../config/format"));
class CreateThumnailService {
    constructor(content) {
        this.compositionId = 'Thumbnail';
        this.content = content;
    }
    async execute(bundle, videoFormat = 'portrait') {
        log_1.log(`Getting compositions from ${bundle}`, 'CreateThumnailService');
        const tmpPath = await defaultPaths_1.getPath('tmp');
        const compositions = await renderer_1.getCompositions(bundle, {
            inputProps: { filename: `${this.content.timestamp}.json`, tmpPath },
        });
        const video = compositions.find(c => c.id === this.compositionId);
        if (!video) {
            log_1.error(`Video not found`, 'RenderVideoService');
            return '';
        }
        const thumbnailPath = path_1.default.resolve(tmpPath, `${this.content.timestamp}.jpeg`);
        log_1.log(`Starting render process`, 'CreateThumnailService');
        await renderer_1.renderFrames({
            config: video,
            webpackBundle: bundle,
            onStart: () => log_1.log(`Starting rendering`, 'CreateThumnailService'),
            onFrameUpdate: frame => log_1.log(`Rendered frame ${frame}`, 'CreateThumnailService'),
            parallelism: null,
            outputDir: tmpPath,
            inputProps: { filename: `${this.content.timestamp}.json` },
            composition: {
                id: this.compositionId,
                durationInFrames: 1,
                fps: this.content.fps,
                height: format_1.default[videoFormat].height,
                width: format_1.default[videoFormat].width,
            },
            imageFormat: 'jpeg',
        });
        fs_1.default.renameSync(path_1.default.resolve(tmpPath, 'element-0.jpeg'), thumbnailPath);
        return thumbnailPath;
    }
}
exports.default = CreateThumnailService;
