"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const fs_1 = tslib_1.__importDefault(require("fs"));
const path_1 = tslib_1.__importDefault(require("path"));
const log_1 = require("../utils/log");
const getFiles_1 = require("../utils/getFiles");
const defaultPaths_1 = require("../config/defaultPaths");
class GetContentService {
    // eslint-disable-next-line
    async execute(filename) {
        const contentPath = await defaultPaths_1.getPath('content');
        const contentFilePath = filename
            ? path_1.default.resolve(contentPath, filename)
            : await getFiles_1.getLatestFileCreated('json', contentPath);
        log_1.log(`Getting content from ${contentFilePath}`, 'GetContentService');
        try {
            const content = fs_1.default.readFileSync(contentFilePath, {
                encoding: 'utf-8',
            });
            const jsonContent = JSON.parse(content);
            return jsonContent;
        }
        catch {
            log_1.error(`${contentFilePath} not found`, 'GetContentService');
            process.exit(1);
        }
    }
}
exports.default = GetContentService;
