"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const path_1 = tslib_1.__importDefault(require("path"));
const renderer_1 = require("@remotion/renderer");
const log_1 = require("../utils/log");
const defaultPaths_1 = require("../config/defaultPaths");
const format_1 = tslib_1.__importDefault(require("../config/format"));
const bar_1 = tslib_1.__importDefault(require("../utils/CliProgress/bar"));
class RenderVideoService {
    constructor(content) {
        this.compositionId = 'Main';
        this.content = content;
    }
    async execute(bundle, videoFormat, withIntro, destination) {
        log_1.log(`Getting compositions from ${bundle}`, 'RenderVideoService');
        const tmpPath = await defaultPaths_1.getPath('tmp');
        const compositions = await renderer_1.getCompositions(bundle, {
            inputProps: {
                filename: `${this.content.timestamp}.json`,
                tmpPath,
            },
        });
        const video = compositions.find(c => c.id === this.compositionId);
        if (!video) {
            log_1.error(`Video not found`, 'RenderVideoService');
            return '';
        }
        const outputVideoPath = path_1.default.resolve(tmpPath, `${this.content.timestamp}.mp4`);
        log_1.log(`Rendering frames`, 'RenderVideoService');
        let renderProgressBar = {};
        await renderer_1.renderMedia({
            webpackBundle: bundle,
            onStart: ({ frameCount: total }) => {
                renderProgressBar = new bar_1.default({
                    initValue: 0,
                    total,
                    text: '[RenderVideoService] Progress {bar} {percentage}% | ETA: {eta}s | {value}/{total} | Rate: {rate}',
                });
            },
            onProgress: ({ renderedFrames }) => {
                renderProgressBar.update(renderedFrames);
            },
            parallelism: null,
            outputLocation: outputVideoPath,
            inputProps: {
                filename: `${this.content.timestamp}.json`,
                withoutIntro: !withIntro,
                destination,
                tmpPath,
            },
            composition: {
                id: this.compositionId,
                durationInFrames: (this.content.fullDuration || 1) * this.content.fps,
                fps: this.content.fps,
                width: format_1.default[videoFormat].width,
                height: format_1.default[videoFormat].height,
            },
            imageFormat: 'jpeg',
            codec: 'h264',
        });
        renderProgressBar.stop();
        return outputVideoPath;
    }
}
exports.default = RenderVideoService;
