"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AudioWaveform = void 0;
const tslib_1 = require("tslib");
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const remotion_1 = require("remotion");
const media_utils_1 = require("@remotion/media-utils");
const loadFromTmp_1 = tslib_1.__importDefault(require("../utils/loadFromTmp"));
const AudioWaveform = ({ audioFilePath }) => {
    const { width: videoWidth, durationInFrames } = remotion_1.useVideoConfig();
    const frame = remotion_1.useCurrentFrame();
    const BAR_WIDTH = 7;
    const BAR_MARGIN_BETWEEN = 2;
    const MAX_BAR_HEIGHT = 100;
    const QUANTITY_OF_SAMPLES = durationInFrames / 1.5;
    const [audioSrc, setAudioSrc] = react_1.useState(null);
    const [waveforms, setWaveforms] = react_1.useState(null);
    react_1.useEffect(() => {
        loadFromTmp_1.default(audioFilePath).then(async (audio) => {
            setAudioSrc(audio);
            const audioData = await media_utils_1.getAudioData(audio);
            const fullWaveforms = Array.from(audioData.channelWaveforms[0]);
            const blockSize = Math.floor(fullWaveforms.length / QUANTITY_OF_SAMPLES);
            const blocks = new Array(Math.floor(fullWaveforms.length / blockSize))
                .fill(0)
                .map((_) => fullWaveforms.splice(0, blockSize));
            const waveformValues = blocks
                .map((block) => block.reduce((accumulator, value) => accumulator + Math.abs(value), 0) / block.length)
                .filter((value) => !!value);
            const multiplier = Math.pow(Math.max(...waveformValues), -1);
            const smoothWaveforms = waveformValues.map((value, index, array) => {
                const weightOfMean = 5;
                const toSmooth = [
                    array[index - 1],
                    value * 3,
                    array[index + 1],
                ];
                const smootherValue = toSmooth.reduce((acc, value) => acc + value, 0) /
                    weightOfMean;
                return smootherValue * multiplier;
            });
            setWaveforms(smoothWaveforms);
        });
    }, [audioFilePath]);
    if (!waveforms || !audioSrc) {
        return null;
    }
    const position = remotion_1.interpolate(frame, [10, durationInFrames - 20], [0, 100]);
    return (jsx_runtime_1.jsxs(jsx_runtime_1.Fragment, { children: [jsx_runtime_1.jsx(remotion_1.Audio, { src: audioSrc }, void 0),
            jsx_runtime_1.jsx("div", Object.assign({ style: {
                    display: 'flex',
                    flexDirection: 'row',
                    alignItems: 'center',
                    height: MAX_BAR_HEIGHT + 50,
                    width: waveforms.length * (BAR_WIDTH + BAR_MARGIN_BETWEEN),
                    transform: `translateX(calc(${videoWidth}px - ${position}%))`,
                } }, { children: waveforms.map((v, i) => {
                    const height = MAX_BAR_HEIGHT * v;
                    return (jsx_runtime_1.jsx("div", { style: {
                            height,
                            width: BAR_WIDTH,
                            backgroundColor: '#fff' || '#282B4B',
                            marginLeft: BAR_MARGIN_BETWEEN,
                            borderRadius: 10,
                        } }, i));
                }) }), void 0)] }, void 0));
};
exports.AudioWaveform = AudioWaveform;
