"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.YoutubeWrapper = void 0;
const tslib_1 = require("tslib");
const jsx_runtime_1 = require("react/jsx-runtime");
const remotion_1 = require("remotion");
const styled_components_1 = tslib_1.__importDefault(require("styled-components"));
const ai_1 = require("react-icons/ai");
const io_1 = require("react-icons/io");
const ri_1 = require("react-icons/ri");
const bs_1 = require("react-icons/bs");
const date_fns_1 = require("date-fns");
const pt_BR_1 = tslib_1.__importDefault(require("date-fns/locale/pt-BR"));
const YT_Logo_svg_1 = tslib_1.__importDefault(require("../../../assets/YT-Logo.svg"));
const Avatar_png_1 = tslib_1.__importDefault(require("../../../assets/Avatar.png"));
const click_mp3_1 = tslib_1.__importDefault(require("../../../assets/click.mp3"));
const VideoWrapper = styled_components_1.default.div `
	background: #0c2d48;
	display: flex;
	flex-direction: column;
	width: ${(props) => props.videoWidth}px;
	height: ${(props) => props.videoHeight}px;
	justify-content: space-between;
	transform: scale(0.63) translate(-25%, -25%);
	overflow: hidden;
`;
const Footer = styled_components_1.default.footer `
	transform: translateY(-370px);
	margin: 0 3.5rem;
	max-width: ${(props) => props.videoWidth * 0.63}px;
	font-family: ProductSans;
	position: relative;
	margin-bottom: 1rem;

	h1 {
		font-weight: 400;
		color: #fff;
		margin: 1rem 0 0.3rem;
	}

	> div:nth-child(2) {
		padding-bottom: 7px;
		border-bottom: 1px solid #323232;
	}

	div {
		display: flex;
		align-items: center;
		justify-content: space-between;
		gap: 2rem;
		color: #999;

		span {
			font-weight: 400;
			font-size: 1.5rem;
			color: #999;

			+ span {
				margin-left: 1rem;
				padding-left: 1rem;
				position: relative;

				&::before {
					content: '';
					width: 4px;
					height: 4px;
					border-radius: 2px;
					background-color: #999;
					position: absolute;
					top: 50%;
					left: 0;
					transform: translate(-50%, -50%);
				}
			}
		}

		section {
			margin-bottom: -0.875rem;
			padding-bottom: 0.5rem;
			display: flex;
			align-items: center;
			gap: 2rem;
			color: #999;
		}

		text {
			display: flex;
			align-items: center;
			gap: 0.5rem;
			font-size: 1.7rem;
			text-transform: uppercase;
		}
	}

	hr {
		margin-top: 0.35rem;
		background-color: #32323210;
	}
`;
const Aside = styled_components_1.default.aside `
	transform: translateX(-590px);
	padding: 2rem 0;
	width: 35rem;
	display: flex;
	flex-direction: column;
	gap: 2rem;

	div {
		display: flex;

		main {
			width: 14rem;
			height: 7.88rem;
			background: #121212;
			margin-right: 1rem;
		}

		p {
			display: flex;
			flex-direction: column;
			margin: 0;
			gap: 1rem;

			strong {
				height: 2.3rem;
				width: 17rem;
				background: #121212;
			}

			span {
				height: 1.7rem;
				width: 12rem;
				background: #121212;
			}
		}
	}
`;
const YoutubeWrapper = ({ children, title }) => {
    const { width: videoWidth, height: videoHeight, durationInFrames, } = remotion_1.useVideoConfig();
    const frame = remotion_1.useCurrentFrame();
    const startScaleAnimationAtFrame = 30;
    const startClickAnimationAtFrame = 50 + startScaleAnimationAtFrame;
    //Mouse movement
    const moveY = remotion_1.interpolate(frame, [0, 50, 57, 73, 90, 110, 115, 125, 150].map((value) => value + startClickAnimationAtFrame), [-50, 95, 93, 97, 20, 10, 15, 12, -50]);
    const moveX = remotion_1.interpolate(frame, [0, 50, 57, 73, 90, 110, 115, 125, 150].map((value) => value + startClickAnimationAtFrame), [370, 650, 657, 655, 40, 50, 45, 48, 150]);
    const colorsClick = remotion_1.interpolateColors(frame, [0, 50, 57, 73, 90, 110, 115, 125, 150].map((value) => value + startClickAnimationAtFrame), ['#fff', '#fff', '#aaa', '#fff', '#fff', '#fff', '#aaa', '#fff', '#fff']);
    //Scale change
    const scale = remotion_1.interpolate(frame, [
        0,
        0 + startScaleAnimationAtFrame,
        startClickAnimationAtFrame,
        200 + startScaleAnimationAtFrame,
        250 + startScaleAnimationAtFrame,
        durationInFrames,
    ], [1.57, 1.57, 1, 1, 1.57, 1.57]);
    const translateX = remotion_1.interpolate(frame, [
        0,
        0 + startScaleAnimationAtFrame,
        startClickAnimationAtFrame,
        200 + startScaleAnimationAtFrame,
        250 + startScaleAnimationAtFrame,
        durationInFrames,
    ], [16.3, 16.3, 0, 0, 16.3, 16.3]);
    const translateY = remotion_1.interpolate(frame, [
        0,
        0 + startScaleAnimationAtFrame,
        startClickAnimationAtFrame,
        200 + startScaleAnimationAtFrame,
        250 + startScaleAnimationAtFrame,
        durationInFrames,
    ], [7.3, 7.3, 0, 0, 7.3, 7.3]);
    return (jsx_runtime_1.jsxs("div", Object.assign({ style: {
            transform: `scale(${scale}) translate(${translateX}%, ${translateY}%)`,
            background: '#212121',
        } }, { children: [jsx_runtime_1.jsx(remotion_1.Sequence, Object.assign({ from: 47 + startClickAnimationAtFrame, durationInFrames: Infinity }, { children: jsx_runtime_1.jsx(remotion_1.Audio, { src: click_mp3_1.default, startFrom: 30 }, void 0) }), void 0),
            jsx_runtime_1.jsx(remotion_1.Sequence, Object.assign({ from: 105 + startClickAnimationAtFrame, durationInFrames: Infinity }, { children: jsx_runtime_1.jsx(remotion_1.Audio, { src: click_mp3_1.default, startFrom: 30 }, void 0) }), void 0),
            jsx_runtime_1.jsxs("header", Object.assign({ style: {
                    background: '#202020',
                    padding: '1rem',
                    display: 'flex',
                    justifyContent: 'space-between',
                    alignItems: 'center',
                    width: videoWidth,
                } }, { children: [jsx_runtime_1.jsxs("div", Object.assign({ style: { display: 'flex', alignItems: 'center', gap: '2rem' } }, { children: [jsx_runtime_1.jsx(ai_1.AiOutlineMenu, { size: "3rem", color: "#fff" }, void 0),
                            jsx_runtime_1.jsx("img", { src: YT_Logo_svg_1.default }, void 0)] }), void 0),
                    jsx_runtime_1.jsxs("div", Object.assign({ style: { display: 'flex', alignItems: 'center', gap: '0' } }, { children: [jsx_runtime_1.jsx("div", { style: {
                                    height: '3rem',
                                    width: 700,
                                    background: '#121212',
                                    border: '1px solid #323232',
                                    borderRadius: '3px 0 0 3px',
                                } }, void 0),
                            jsx_runtime_1.jsx("div", Object.assign({ style: {
                                    height: '3rem',
                                    width: 130,
                                    background: '#323232',
                                    border: '1px solid #323232',
                                    borderRadius: '0 3px 3px 0',
                                    display: 'flex',
                                    justifyContent: 'center',
                                    alignItems: 'center',
                                } }, { children: jsx_runtime_1.jsx(ai_1.AiOutlineSearch, { color: "#999", size: "1.8rem" }, void 0) }), void 0),
                            jsx_runtime_1.jsx(io_1.IoMdMic, { style: { marginLeft: '1rem' }, size: "2rem", color: "#fff" }, void 0)] }), void 0),
                    jsx_runtime_1.jsx("div", Object.assign({ style: { display: 'flex', alignItems: 'center', gap: '2rem' } }, { children: jsx_runtime_1.jsx("img", { src: Avatar_png_1.default, style: {
                                width: '2.75rem',
                                height: '2.75rem',
                                borderRadius: '2rem',
                                marginRight: '2rem',
                            } }, void 0) }), void 0)] }), void 0),
            jsx_runtime_1.jsxs("div", Object.assign({ style: { display: 'flex', flexDirection: 'row' } }, { children: [jsx_runtime_1.jsxs("main", { children: [jsx_runtime_1.jsx(VideoWrapper, Object.assign({ videoWidth: videoWidth, videoHeight: videoHeight }, { children: children }), void 0),
                            jsx_runtime_1.jsxs(Footer, Object.assign({ videoWidth: videoWidth }, { children: [jsx_runtime_1.jsxs("h1", { children: ["[CodeStack News] ", title] }, void 0),
                                    jsx_runtime_1.jsxs("div", { children: [jsx_runtime_1.jsxs("p", { children: [jsx_runtime_1.jsxs("span", { children: [Math.round(frame / 3), " Visualiza\u00E7\u00F5es"] }, void 0),
                                                    jsx_runtime_1.jsx("span", { children: date_fns_1.format(new Date(), "dd 'de' MMM. 'de' yyyy", {
                                                            locale: pt_BR_1.default,
                                                        }) }, void 0)] }, void 0),
                                            jsx_runtime_1.jsxs("div", { children: [jsx_runtime_1.jsxs("section", Object.assign({ style: {
                                                            borderBottom: `3px solid ${frame >=
                                                                57 + startClickAnimationAtFrame
                                                                ? '#3EA6FF'
                                                                : ''}`,
                                                        } }, { children: [jsx_runtime_1.jsxs("text", Object.assign({ style: {
                                                                    color: frame >=
                                                                        57 + startClickAnimationAtFrame
                                                                        ? '#3EA6FF'
                                                                        : '',
                                                                } }, { children: [jsx_runtime_1.jsx(io_1.IoMdThumbsUp, { size: "3rem" }, void 0), Math.round(frame / 10)] }), void 0),
                                                            jsx_runtime_1.jsxs("text", { children: [jsx_runtime_1.jsx(io_1.IoMdThumbsDown, { size: "3rem" }, void 0), " 0"] }, void 0)] }), void 0),
                                                    jsx_runtime_1.jsxs("text", { children: [jsx_runtime_1.jsx(io_1.IoIosShareAlt, { size: "3rem" }, void 0), "Compartilhar"] }, void 0),
                                                    jsx_runtime_1.jsxs("text", { children: [jsx_runtime_1.jsx(ri_1.RiPlayListAddLine, { size: "2rem" }, void 0), "Salvar"] }, void 0),
                                                    jsx_runtime_1.jsx(bs_1.BsThreeDots, { size: "3rem" }, void 0)] }, void 0)] }, void 0),
                                    jsx_runtime_1.jsxs("div", Object.assign({ style: { margin: '0.5rem 0' } }, { children: [jsx_runtime_1.jsxs("div", { children: [jsx_runtime_1.jsx("img", { src: Avatar_png_1.default, style: {
                                                            width: '4.5rem',
                                                            height: '4.5rem',
                                                            borderRadius: '2.5rem',
                                                            marginRight: '0rem',
                                                        } }, void 0),
                                                    jsx_runtime_1.jsxs("p", Object.assign({ style: {
                                                            display: 'flex',
                                                            flexDirection: 'column',
                                                        } }, { children: [jsx_runtime_1.jsx("strong", Object.assign({ style: {
                                                                    fontSize: '1.5rem',
                                                                    color: '#fff',
                                                                } }, { children: "CodeStack" }), void 0),
                                                            jsx_runtime_1.jsxs("span", { children: [Math.round(frame / 15), " inscritos"] }, void 0)] }), void 0)] }, void 0),
                                            jsx_runtime_1.jsx("p", Object.assign({ style: {
                                                    background: frame >=
                                                        115 + startClickAnimationAtFrame
                                                        ? '#303030'
                                                        : '#CC0000',
                                                    color: '#fff',
                                                    fontSize: '1.7rem',
                                                    textTransform: 'uppercase',
                                                    padding: '1rem 2rem',
                                                    margin: 0,
                                                    borderRadius: 5,
                                                } }, { children: frame >= 115 + startClickAnimationAtFrame
                                                    ? 'Inscrito'
                                                    : 'Inscreva-se' }), void 0)] }), void 0),
                                    jsx_runtime_1.jsx("div", Object.assign({ style: {
                                            position: 'absolute',
                                            bottom: moveY,
                                            right: moveX, //370 -> 670 -> 50 -> 150
                                        } }, { children: jsx_runtime_1.jsx("svg", Object.assign({ width: "3rem", height: "3rem", viewBox: "0 0 23 25", fill: "none", xmlns: "http://www.w3.org/2000/svg" }, { children: jsx_runtime_1.jsx("g", Object.assign({ clipPath: "url(#prefix__clip0)" }, { children: jsx_runtime_1.jsx("path", { d: "M22.326 11.773v4.5c0 .145-.018.29-.053.43l-1.571 6.375c-.209.847-1 1.445-1.912 1.445H8.576c-.31 0-.616-.07-.892-.204a1.944 1.944 0 01-.697-.568l-6.285-8.25c-.639-.837-.445-2.01.433-2.619.877-.609 2.106-.424 2.744.414l1.554 2.04V2.398c0-1.035.88-1.875 1.964-1.875 1.085 0 1.964.84 1.964 1.875v9.375h.393V9.898c0-1.035.88-1.875 1.965-1.875 1.084 0 1.964.84 1.964 1.875v1.875h.393v-1.125c0-1.035.88-1.875 1.964-1.875 1.085 0 1.964.84 1.964 1.875v1.125h.393c0-1.035.88-1.875 1.964-1.875 1.085 0 1.965.84 1.965 1.875zm-12.572 3.75h-.393v4.5h.393v-4.5zm4.322 0h-.393v4.5h.393v-4.5zm4.321 0h-.393v4.5h.393v-4.5z", fill: colorsClick }, void 0) }), void 0) }), void 0) }), void 0)] }), void 0)] }, void 0),
                    jsx_runtime_1.jsx(Aside, { children: new Array(7).fill(0).map((_, i) => {
                            return (jsx_runtime_1.jsxs("div", { children: [jsx_runtime_1.jsx("main", {}, void 0),
                                    jsx_runtime_1.jsxs("p", { children: [jsx_runtime_1.jsx("strong", {}, void 0),
                                            jsx_runtime_1.jsx("span", {}, void 0)] }, void 0)] }, i));
                        }) }, void 0)] }), void 0)] }), void 0));
};
exports.YoutubeWrapper = YoutubeWrapper;
